@@ -6,18 +6,9 @@
  * Date        : 2019-09-08
  * Description : RAW Import digiKam plugin definition.
  *
- * Copyright (C) 2019-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * SPDX-FileCopyrightText: 2019-2024 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
- * This program is free software; you can redistribute it
- * and/or modify it under the terms of the GNU General
- * Public License as published by the Free Software Foundation;
- * either version 2, or (at your option)
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  * ============================================================ */
 
@@ -81,6 +72,11 @@ public:
      */
     virtual bool run(const QString& path, const DRawDecoding& def) = 0;
 
+    /**
+     * Return the path to the raw program, or empty if not found.
+     */
+    virtual QString getRawProgram() const;
+
 Q_SIGNALS:
 
     /**
